package com.fs.system.oss;

import com.fs.common.exception.file.OssException;
import com.obs.services.ObsClient;
import com.obs.services.exception.ObsException;
import com.obs.services.model.PutObjectRequest;
import org.apache.commons.io.IOUtils;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.TimeZone;

/**
 * 腾讯云存储
 */
public class HuaweiCloudStorageService extends CloudStorageService
{
    private ObsClient client;

    public HuaweiCloudStorageService(CloudStorageConfig config)
    {
        this.config = config;
        // 初始化
        init();
    }

    private void init()
    {
        client = new ObsClient(config.getHuaweiAK(), config.getHuaweiSK(), config.getHuaweiEndpoint());
    }
    public static String generateUploadFileName(String fileName) {
        // 获取文件扩展名
        String fileExtension = "";
        int i = fileName.lastIndexOf('.');
        if (i > 0) {
            fileExtension = fileName.substring(i + 1);
        }

        // 获取当前时间戳
        long currentTimeMillis = System.currentTimeMillis();

        // 生成上传文件名
        String uploadFileName = currentTimeMillis + "." + fileExtension;

        // 获取当前日期
        Date date = new Date();
        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyyMMdd");
        dateFormat.setTimeZone(TimeZone.getTimeZone("UTC"));
        String uploadDay = dateFormat.format(date);

        // 生成上传路径
        String key = "fs/" + uploadDay + "/" + uploadFileName;

        return key;
    }
    @Override
    public String upload(byte[] data, String path)
    {
        String objKey = generateUploadFileName(path);
        try {
            // 文件上传
            com.obs.services.model.PutObjectRequest request = new PutObjectRequest(config.getHuaweiBucketName(), objKey,new ByteArrayInputStream(data));

            client.putObject(request);
        } catch (ObsException e) {
            throw new ObsException("文件上传失败，" + e.getErrorMessage());
        } catch (Exception e) {
            System.out.println("上传失败");
            // 其他异常信息打印
            return "上传失败"+e.getMessage();
        }
        return config.getHuaweiDomain()+"/"+ objKey;

    }

    @Override
    public String upload(InputStream inputStream, String path)
    {
        try
        {
            byte[] data = IOUtils.toByteArray(inputStream);
            return this.upload(data, path);
        }
        catch (IOException e)
        {
            throw new OssException("上传文件失败");
        }
    }

    @Override
    public String uploadSuffix(byte[] data, String suffix)
    {
        return upload(data, getPath(config.getQcloudPrefix(), suffix));
    }

    @Override
    public String uploadSuffix(InputStream inputStream, String suffix)
    {
        return upload(inputStream, getPath(config.getQcloudPrefix(), suffix));
    }
}
